summaryrefslogtreecommitdiffstats
path: root/src/lib/dhcpsrv/cfg_option.h
diff options
context:
space:
mode:
authorMarcin Siodelski <marcin@isc.org>2019-06-17 14:07:36 +0200
committerMarcin Siodelski <marcin@isc.org>2019-06-27 20:51:31 +0200
commit90a950d1089a3c91efecce8881d4ee6db9c31920 (patch)
treefa8bf769de4f2d32bf1e86b9b44c26dd7acbcb3a /src/lib/dhcpsrv/cfg_option.h
parent[#642,!373] Check that it is possible to delete global param for server tag (diff)
downloadkea-90a950d1089a3c91efecce8881d4ee6db9c31920.tar.xz
kea-90a950d1089a3c91efecce8881d4ee6db9c31920.zip
[#642,!373] Extended StampedElement to hold multiple server tags.
Diffstat (limited to 'src/lib/dhcpsrv/cfg_option.h')
-rw-r--r--src/lib/dhcpsrv/cfg_option.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/lib/dhcpsrv/cfg_option.h b/src/lib/dhcpsrv/cfg_option.h
index 58800734db..bc61ef7bc0 100644
--- a/src/lib/dhcpsrv/cfg_option.h
+++ b/src/lib/dhcpsrv/cfg_option.h
@@ -233,21 +233,21 @@ typedef boost::multi_index_container<
>
>,
// Start definition of index #3.
// Use StampedElement::getModificationTime as a key.
boost::multi_index::ordered_non_unique<
boost::multi_index::const_mem_fun<
- data::StampedElement,
+ data::BaseStampedElement,
boost::posix_time::ptime,
- &data::StampedElement::getModificationTime
+ &data::BaseStampedElement::getModificationTime
>
>,
// Start definition of index #4.
// Use StampedElement::getId as a key.
boost::multi_index::hashed_non_unique<
boost::multi_index::tag<OptionIdIndexTag>,
- boost::multi_index::const_mem_fun<data::StampedElement, uint64_t,
- &data::StampedElement::getId>
+ boost::multi_index::const_mem_fun<data::BaseStampedElement, uint64_t,
+ &data::BaseStampedElement::getId>
>
>
> OptionContainer;
@@ -233,21 +233,21 @@ typedef boost::multi_index_container<
>,
// Start definition of index #3.
- // Use StampedElement::getModificationTime as a key.
+ // Use BaseStampedElement::getModificationTime as a key.
boost::multi_index::ordered_non_unique<
boost::multi_index::const_mem_fun<
@@ -233,21 +233,21 @@ typedef boost::multi_index_container<
>,
// Start definition of index #4.
- // Use StampedElement::getId as a key.
+ // Use BaseStampedElement::getId as a key.
boost::multi_index::hashed_non_unique<
boost::multi_index::tag<OptionIdIndexTag>,